==> sli-plots-0.0.24.tgz: package/addon/components/current-value-dot.js <==
import Component from '@glimmer/component';
import { tracked } from '@glimmer/tracking';

export default class CurrentValueDotComponent extends Component {
  @tracked svg;

  // CONFIG
  get color() {
    return this.args.color || 'black';
  }

  get radius() {
    return this.args.radius || 3;
  }

  get yKey() {
    return this.args.yKey || 'ABS_AVG';
  }

  get xKey() {
    return this.args.xKey || 'OCCURED';
  }

  // COMPUTED
  get noData() {
    return !this.args.dataset || !this.args.dataset.length;
  }

  get datapoint() {
    return this.noData
      ? null
      : this.args.dataset[this.args.dataset.length - 1];
  }

  get dimensions() {
    return this.svg ? this.svg.getBoundingClientRect() : {};
  }

  findSvg = (el) => {
    this.svg = el.closest('svg');
  }

  // Returns x, y coordinates of dot
  // returns {x: , y: }
  get location() {
    if (this.noData || !this.svg) return { x: -100, y: -100 };
    return {
      x: this.getClampedX(),
      y: this.getClampedY()
    }
  }

  // Get x location but shift so that its always inside of chart
  getClampedX() {
    const xValue = new Date(this.datapoint[this.xKey]);
    const xLoc = this.args.xScale(xValue);
    if ( xLoc < 0 + this.radius ) {
      return this.radius;
    } else if (xLoc > this.dimensions.width - this.radius) {
      return this.dimensions.width - this.radius;
    } else {
      return xLoc;
    }
  }

  // Get y location but shift so thats its always inside of chart (not cut off)
  getClampedY() {
    const yValue = this.datapoint[this.yKey];
    const yLoc = this.args.yScale(yValue);
    if (yLoc < 0 + this.radius) {
      return this.radius;
    } else if (yLoc > this.dimensions.height - this.radius) {
      return this.dimensions.height - this.radius;
    } else {
      return yLoc;
    }
  }
}

==> sli-plots-0.0.26.tgz: package/addon/components/current-value-dot.js <==
import Component from '@glimmer/component';
import { tracked } from '@glimmer/tracking';

export default class CurrentValueDotComponent extends Component {
  @tracked svg;

  // CONFIG
  get color() {
    return this.args.color || 'black';
  }

  get radius() {
    return this.args.radius || 3;
  }

  get yKey() {
    return this.args.yKey || 'SUM';
  }

  get xKey() {
    return this.args.xKey || 'OCCURED';
  }

  // COMPUTED
  get noData() {
    return !this.args.dataset || !this.args.dataset.length;
  }

  get datapoint() {
    return this.noData
      ? null
      : this.args.dataset[this.args.dataset.length - 1];
  }

  get dimensions() {
    return this.svg ? this.svg.getBoundingClientRect() : {};
  }

  findSvg = (el) => {
    this.svg = el.closest('svg');
  }

  // Returns x, y coordinates of dot
  // returns {x: , y: }
  get location() {
    if (this.noData || !this.svg) return { x: -100, y: -100 };
    return {
      x: this.getClampedX(),
      y: this.getClampedY()
    }
  }

  // Get x location but shift so that its always inside of chart
  getClampedX() {
    const xValue = new Date(this.datapoint[this.xKey]);
    const xLoc = this.args.xScale(xValue);
    if ( xLoc < 0 + this.radius ) {
      return this.radius;
    } else if (xLoc > this.dimensions.width - this.radius) {
      return this.dimensions.width - this.radius;
    } else {
      return xLoc;
    }
  }

  // Get y location but shift so thats its always inside of chart (not cut off)
  getClampedY() {
    const yValue = this.datapoint[this.yKey];
    const yLoc = this.args.yScale(yValue);
    if (yLoc < 0 + this.radius) {
      return this.radius;
    } else if (yLoc > this.dimensions.height - this.radius) {
      return this.dimensions.height - this.radius;
    } else {
      return yLoc;
    }
  }
}
